C                               PROGRAM TRACER II                        9CA0030
C                                                                        9CA0040
C     DESCRIPTION.   LATTICE TRANSFORMATION - CELL REDUCTION PROGRAM     9CA0050
C     AUTHOR         S. L. LAWTON, MOBIL RESEARCH AND DEVELOPMENT CORP., 9CA0060
C                    RESEARCH DEPT., PAULSBORO, NEW JERSEY 08066.        9CA0061
C     LANGUAGE.      FORTRAN IV FOR IBM 7040    (APRIL 1967)             9CA0070
C                    FORTRAN IV FOR IBM 360/44  (OCTOBER 1970)           9CA0071
C                                                                        9CA0080
C     INPUT DATA                                                         9CA0090
C                                                                        9CA0100
C  1. TITLE CARD -- FORMAT(35A2) -- ONE CARD.                            9CA0110
C                                                                        9CA0120
C          ANY ALPHANUMERIC INFORMATION DESCRIBING THE COMPOUND.  THIS   9CA0130
C          WILL BE PRINTED BACK OUT AS A HEADING ON EACH PAGE OF OUTPUT. 9CA0140
C                                                                        9CA0150
C  2. CONTROL CARD -- FORMAT(I3,F7.3) -- ONE CARD.                       9CA0160
C                                                                        9CA0170
C       COL. 1-3   INPUT =1 CELL PARAMETERS ON PARAMETER CARD ARE IN     9CA0180
C                           DIRECT SPACE                                 9CA0190
C                        =2 CELL PARAMETERS ON PARAMETER CARD ARE IN     9CA0200
C                           RECIPROCAL SPACE                             9CA0210
C       COL. 4-10   DEL     ABSOLUTE VALUE OF THE LARGEST PERMISSIBLE    9CA0220
C                           DIFFERENCE BETWEEN ANY TWO OF THE SIX RE-    9CA0230
C                           DUCED CELL SCALAR PRODUCTS.  (FOR LATTICE    9CA0240
C                           PARAMETERS WITH E.S.D. OF 1 PART IN 10000 A. 9CA0250
C                           DEL = 0.10 IS SATISFACTORY.  IF ABOUT 1 PART 9CA0260
C                           IN 1000 A., DEL = 0.50 TO 1.00 MAY BE        9CA0270
C                           NECESSARY.)                                  9CA0280
C                           THIS FIELD IS IRRELAVENT IF NO CELL          9CA0290
C                           REDUCTION IS TO BE MADE.                     9CA0300
C                                                                        9CA0310
C  3. PARAMETER CARD -- FORMAT(6F10.6) -- ONE CARD                       9CA0320
C                                                                        9CA0330
C       COL. 1-10    A      LATTICE PARAMETER A (OR A*)                  9CA0340
C       COL.11-20    B      LATTICE PARAMETER B (OR B*)                  9CA0350
C       COL.21-30    C      LATTICE PARAMETER C (OR C*)                  9CA0360
C       COL.31-40  ALPHA    LATTICE PARAMETER ALPHA (OR ALPHA*)          9CA0370
C       COL.41-50  BETA     LATTICE PARAMETER BETA  (OR BETA*)           9CA0380
C       COL.51-60  GAMMA    LATTICE PARAMETER GAMMA (OR GAMMA*)          9CA0390
C          (NOTE.  THE CELL EDGES ARE IN UNITS OF ANGSTROMS (IF INPUT=1) 9CA0400
C          AND INVERSE ANGSTROMS (IF INPUT=2).  ALL ANGLES ARE IN        9CA0410
C          DEGREES AND DECIMAL FRACTION.)                                9CA0420
C                                                                        9CA0430
C  4. INSTRUCTION CARDS -- FORMAT(I3,2X,25A3).                           9CA0440
C                                                                        9CA0450
C          THESE CARDS FUNCTION AS THE COMMANDS TO THE PROGRAM IN TRANS- 9CA0460
C          FORMING ONE CELL TO ANOTHER.  EACH CARD CONTAINS TWO ITEMS--  9CA0470
C          AN INSTRUCTION NUMBER (NQ) AND THE BRAVAIS LATTICE            9CA0480
C          DESCRIPTION OF THE CELL ON WHICH THE PROGRAM WILL OPERATE.    9CA0490
C          AS MANY CARDS AS ARE NECESSARY MAY BE USED TO COMPLETE THE    9CA0500
C          DESIRED SUCCESSIVE TRANSFORMATIONS FOR ANY ONE COMPOUND.      9CA0510
C          THEIR ORDER SPECIFIES TO THE PROGRAM THE ORDER IN WHICH THE   9CA0520
C          TRANSFORMATIONS ARE TO BE EXECUTED.    THE LAST INSTRUCTION   9CA0530
C          CARD FOR A PARTICULAR SEQUENCE OF TRANSFORMATIONS MUST HAVE   9CA0540
C          NQ = 7 OR 8.  BOTH MAY NOT BE PRESENT AND NEITHER MAY PRECEDE 9CA0550
C          ANY WITH NQ = 1,2,3,4,5 OR 6.  NQ = 7 TRIGGERS CELL REDUCTION 9CA0560
C          AND NQ = 8 MERELY IDENTIFIES THE LAST CELL IN A SEQUENCE TO   9CA0570
C          WHICH A TRANSFORMATION IS TO BE MADE WHEN NO CELL REDUCTION   9CA0580
C          IS PERFORMED.  THUS, INSTRUCTION CARDS ARE READ UNTIL THE     9CA0590
C          PROGRAM FINDS ONE WITH NQ = 7 OR 8.  INSTRUCTION CARDS WITH   9CA0600
C          NQ.LE.6 MAY BE INTERMIXED.                                    9CA0610
C                                                                        9CA0620
C                INSTR. CODE                INSTRUCTION                  9CA0630
C                                                                        9CA0640
C       COL. 3      NQ = 1  TRANSFORM THIS CELL TO A NEW CELL USING A    9CA0650
C                           MATRIX SUPPLIED BY THE USER ON THE CORRE-    9CA0660
C                           SPONDING TRANSFORMATION CARD.                9CA0670
C                      = 2  THIS CELL IS A-CENTERED.  THE PROGRAM WILL   9CA0680
C                           TRANSFORM IT TO A PRIMITIVE CELL USING A     9CA0690
C                           MATRIX IN SUBROUTINE CENTER.                 9CA0700
C                      = 3  THIS CELL IS B-CENTERED.  THE PROGRAM WILL   9CA0710
C                           TRANSFORM IT TO A PRIMITIVE CELL USING A     9CA0720
C                           MATRIX IN SUBROUTINE CENTER.                 9CA0730
C                      = 4  THIS CELL IS C-CENTERED.  THE PROGRAM WILL   9CA0740
C                           TRANSFORM IT TO A PRIMITIVE CELL USING A     9CA0750
C                           MATRIX IN SUBROUTINE CENTER.                 9CA0760
C                      = 5  THIS CELL IS BODY-CENTERED. THE PROGRAM WILL 9CA0770
C                           TRANSFORM IT TO A PRIMITIVE CELL USING A     9CA0780
C                           MATRIX IN SUBROUTINE CENTER.                 9CA0790
C                      = 6  THIS CELL IS FACE-CENTERED. THE PROGRAM WILL 9CA0800
C                           TRANSFORM IT TO A PRIMITIVE CELL USING A     9CA0810
C                           MATRIX IN SUBROUTINE CENTER.                 9CA0820
C                      = 7  TRANSFORM THIS CELL TO ITS REDUCED CELL AND  9CA0830
C                           THEN IDENTIFY AND GENERATE FROM IT THE UNIT  9CA0840
C                           CELL OF HIGHEST SYMMETRY AND ITS CORRESPOND- 9CA0850
C                           ING LATTICE PARAMETERS.  (ALL TRANSFORMATION 9CA0860
C                           MATRICES FOR THIS INSTRUCTION ARE GENERATED  9CA0870
C                           BY THE PROGRAM.)                             9CA0880
C                      = 8  THIS IS A NON-EXECUTABLE INSTRUCTION NOTIFY- 9CA0890
C                           ING THE PROGRAM THAT NO TRANSFORMATION IS TO 9CA0900
C                           BE APPLIED TO THIS CELL.  THIS INSTRUCTION   9CA0910
C                           CARD MAY BE USED FOR ONE OF TWO PURPOSES.    9CA0920
C                           (A) TO CALCULATE THE INVERSE CELL DATA OF    9CA0930
C                           THE INPUT PARAMETERS, VOLUME AND SIN AND COS 9CA0940
C                           VALUES OF CELL ANGLES, OR (B) TO IDENTIFY    9CA0950
C                           THE NAME OF THE CELL TO WHICH THE PREVIOUS   9CA0960
C                           CELL IS TRANSFORMED WHEN THE PREVIOUS CELL   9CA0970
C                           IN A TRANSFORMATION SEQUENCE INVOLVES ANY    9CA0980
C                           ONE OF THE FOLLOWING INSTRUCTIONS--NQ=1,2,3, 9CA0990
C                           4,5 OR 6.                                    9CA1000
C                                                                        9CA1010
C       COL. 6-80  CELL     ANY ALPHANUMERIC INFORMATION DESCRIBING THE  9CA1020
C                           CELL, E.G., CRYSTAL SYSTEM AND LATTICE TYPE. 9CA1030
C                           LEFT JUSTIFY.  THIS WILL BE PRINTED BACK OUT 9CA1040
C                           AS A HEADING IN THE OUTPUT FOR IDENTIFICA-   9CA1050
C                           TION PURPOSES.                               9CA1060
C                                                                        9CA1070
C  5. TRANSFORMATION CARDS -- FORMAT(9F8.5).                             9CA1080
C                                                                        9CA1090
C          EACH CARD CONTAINS A 3X3 TRANSFORMATION MATRIX (ONE PER CARD) 9CA1100
C          TO BE USED BY THE PROGRAM FOR EACH INSTRUCTION CARD WITH NQ=1 9CA1110
C          AND ARE ARRANGED IN THE SAME ORDER AS ARE THE INSTRUCTION     9CA1120
C          CARDS (WITH NQ=1) WHICH WILL USE THEM.  IF NO INSTRUCTION     9CA1130
C          CARDS ARE PRESENT WITH NQ=1, THESE TRANSFORMATION CARDS ARE   9CA1140
C          OMITTED.                                                      9CA1150
C          (EXAMPLE.  INSTRUCTION CARD NO. 1 HAS NQ=1 AND CARD NO. 2     9CA1160
C          HAS NQ=8.  INSTR. CARD NO. 1 CORRESP. TO CELL NO. 1 AND       9CA1170
C          INSTR. CARD NO. 2 CORRESP. TO CELL NO. 2.  ONE MATRIX CARD    9CA1180
C          IS THEREFORE SUPPLIED WHICH IS USED BY THE PROGRAM TO         9CA1190
C          TRANSFORM CELL 1 TO CELL 2.)                                  9CA1200
C          THE 3X3 MATRIX FOR VECTOR TRANSFORMATION OF UNIT CELL AXES    9CA1210
C          IS DEFINED BY THE USUAL CONVENTION AS FOLLOWS                 9CA1220
C                   NEWA = P(1,1)*A + P(1,2)*B + P(1,3)*C                9CA1230
C                   NEWB = P(2,1)*A + P(2,2)*B + P(2,3)*C                9CA1240
C                   NEWC = P(3,1)*A + P(3,2)*B + P(3,3)*C                9CA1250
C          WHERE A,B,C,NEWA,NEWB,NEWC ARE VECTORS DESCRIBING THE OLD AND 9CA1260
C          NEW CELL RESPECTIVELY.  THE ORDER OF PUNCHING IS P(1,1),      9CA1270
C          P(1,2),P(1,3),P(2,1),P(2,2),P(2,3),P(3,1),P(3,2),P(3,3).      9CA1280
C                                                                        9CA1290
C  6. STOPPER CARD -- 1 IN COL. 72                                       9CA1300
C                                                                        9CA1310
C          ANY NUMBER OF SETS OF DATA MAY BE PROCESSED WITHOUT RELOADING 9CA1320
C          THE PROGRAM.  EACH DATA SET CONSISTS OF ITEMS 1 - 5 ABOVE.    9CA1330

